@@ -59,26 +59,41 @@ class WdlParser:
                 return
         raise ValueError('Could not parse workflow args')
 
-    def __parse_variables_from_block(self, wdl_lines_after_block_start) -> dict[str, WorkflowVar]:
+    def __parse_variables_from_block(self, wdl_lines_after_block_start: list) -> dict[str, WorkflowVar]:
         """
         Internal parsing function which is used both for workflow inputs variables and structs fields
         :param wdl_lines_after_block_start:
-        :return:
+        :return dictionary of workflow variables:
         """
         workflow_vars = {}
+        curly_brackets_scope = 1
+        straight_brackets_scope = 0
 
-        brackets_scope = 1
+        while len(wdl_lines_after_block_start) > 0:
+            # end of inputs block
+            if curly_brackets_scope <= 0:
+                break
+            line = wdl_lines_after_block_start.pop(0)
+            curly_brackets_scope, straight_brackets_scope = \
+                self.__update_scope(curly_brackets_scope, line, straight_brackets_scope)
 
-        for line in wdl_lines_after_block_start:
-            brackets_scope -= line.count('}')
-            brackets_scope += line.count('{')
-            if brackets_scope <= 0:
-                return workflow_vars
+            # inside internal brackets, meaning multiline complex variable default init
+            while curly_brackets_scope > 1 or straight_brackets_scope > 0:
+                next_line = wdl_lines_after_block_start.pop(0)
+                line += next_line
+                curly_brackets_scope, straight_brackets_scope = \
+                    self.__update_scope(curly_brackets_scope, next_line, straight_brackets_scope)
+
+            line = line.strip()
+            if len(line) == 0 or line.startswith('}'):
+                continue
+
+            # parse single-line default value (if default is multiline, will ignore all but first
             equal_split = line.split('=')
             if len(equal_split) == 0 or equal_split == ['']:
                 continue
             var_str = equal_split[0]
-            if len(equal_split) == 2:  # have default value
+            if len(equal_split) == 2:  # has default value
                 default_value_str = equal_split[1].strip()
             else:
                 default_value_str = None
@@ -108,6 +123,13 @@ class WdlParser:
                                                   struct_type)
         return workflow_vars
 
+    def __update_scope(self, curly_brackets_scope, line, straight_brackets_scope):
+        curly_brackets_scope -= line.count('}')
+        curly_brackets_scope += line.count('{')
+        straight_brackets_scope -= line.count(']')
+        straight_brackets_scope += line.count('[')
+        return curly_brackets_scope, straight_brackets_scope
+
     def __parse_structs(self, wdl_file) -> None:
         self.imported_wdls.update({wdl_file})
         wdl_lines = self.__read_wdl_code_lines(wdl_file)
